@@ -1,5 +1,4 @@
 """
-
 tnetstring:  data serialization using typed netstrings
 ======================================================
 
@@ -36,21 +35,22 @@ at once, there's no efficiency gain from using the file-based versions of these
 functions.  They're only here so you can use load() to read precisely one
 item from a file or socket without consuming any extra data.
 
-By default tnetstrings work only with byte strings, not unicode.  If you want
-unicode strings then pass an optional encoding to the various functions, 
-like so::
+The tnetstrings specification explicitly states that strings are binary blobs
+and forbids the use of unicode at the protocol level.  As a convenience to
+python programmers, this library lets you specify an application-level encoding
+to translate python's unicode strings to and from binary blobs:
 
     >>> print repr(tnetstring.loads("2:\\xce\\xb1,"))
     '\\xce\\xb1'
     >>> 
-    >>> print repr(tnetstring.loads("2:\\xce\\xb1,","utf8"))
-    u'\u03b1'
+    >>> print repr(tnetstring.loads("2:\\xce\\xb1,", "utf8"))
+    u'\\u03b1'
 
 """
 
 __ver_major__ = 0
 __ver_minor__ = 2
-__ver_patch__ = 0
+__ver_patch__ = 1
 __ver_sub__ = ""
 __version__ = "%d.%d.%d%s" % (__ver_major__,__ver_minor__,__ver_patch__,__ver_sub__)
 
@@ -390,4 +390,3 @@ else:
     loads = _tnetstring.loads
     pop = _tnetstring.pop
 
-
