@@ -16,7 +16,7 @@
 #include "tns_core.c"
 
 
-//  We have one static tns_ops struct far parsing bytestrings.
+//  We have one static tns_ops struct for parsing bytestrings.
 static tns_ops _tnetstring_ops_bytes;
 
 //  Unicode parsing ops are created on demand.
@@ -136,7 +136,7 @@ _tnetstring_load(PyObject* self, PyObject *args)
   Py_INCREF(res);
   if(!PyString_Check(res) || !PyString_GET_SIZE(res)) {
       PyErr_SetString(PyExc_ValueError,
-                      "Not a tnetstring: invlaid or missing length prefix");
+                      "Not a tnetstring: invalid or missing length prefix");
       goto error;
   }
   c = PyString_AS_STRING(res)[0];
@@ -145,7 +145,7 @@ _tnetstring_load(PyObject* self, PyObject *args)
   //  If the first char is zero, it must be the only char.
   if(c < '0' || c > '9') {
       PyErr_SetString(PyExc_ValueError,
-                      "Not a tnetstring: invlaid or missing length prefix");
+                      "Not a tnetstring: invalid or missing length prefix");
       goto error;
   } else if (c == '0') {
       res = PyObject_CallMethodObjArgs(file, methnm, metharg, NULL);
@@ -155,7 +155,7 @@ _tnetstring_load(PyObject* self, PyObject *args)
       Py_INCREF(res);
       if(!PyString_Check(res) || !PyString_GET_SIZE(res)) {
           PyErr_SetString(PyExc_ValueError,
-                      "Not a tnetstring: invlaid or missing length prefix");
+                      "Not a tnetstring: invalid or missing length prefix");
           goto error;
       }
       c = PyString_AS_STRING(res)[0];
@@ -172,7 +172,7 @@ _tnetstring_load(PyObject* self, PyObject *args)
           Py_INCREF(res);
           if(!PyString_Check(res) || !PyString_GET_SIZE(res)) {
               PyErr_SetString(PyExc_ValueError,
-                        "Not a tnetstring: invlaid or missing length prefix");
+                        "Not a tnetstring: invalid or missing length prefix");
               goto error;
           }
           c = PyString_AS_STRING(res)[0];
@@ -248,6 +248,7 @@ _tnetstring_pop(PyObject* self, PyObject *args)
   PyObject *string = NULL;
   PyObject *val = NULL;
   PyObject *rest = NULL;
+  PyObject *result = NULL;
   PyObject *encoding = Py_None;
   tns_ops *ops = &_tnetstring_ops_bytes;
   char *data, *remain;
@@ -287,7 +288,14 @@ _tnetstring_pop(PyObject* self, PyObject *args)
   }
 
   rest = PyString_FromStringAndSize(remain, len-(remain-data));
-  return PyTuple_Pack(2, val, rest);
+  if(rest == NULL) {
+      result = NULL;
+  } else {
+      result = PyTuple_Pack(2, val, rest);
+      Py_DECREF(rest);
+  }
+  Py_DECREF(val);
+  return result;
 }
 
 
@@ -478,13 +486,39 @@ tns_parse_integer(const tns_ops *ops, const char *data, size_t len)
       }
       return PyLong_FromLongLong(ll * sign);
   }
-  //  Really big numbers must be parsed by python.
-  //  Technically this allows whitespace around the number, which
-  //  isn't valid in a tnetstring.  But I don't want to waste the
-  //  time checking and I am *not* reimplementing arbitrary-precision
-  //  strtod for python.
+  //  Really big numbers are passed to python's native parser.
   else { 
+      // PyLong_FromString allows leading whitespace, so we have to check
+      // that there is none present in the string.
+      c = *data;
+      switch(c) {
+        case '0':
+        case '1':
+        case '2':
+        case '3':
+        case '4':
+        case '5':
+        case '6':
+        case '7':
+        case '8':
+        case '9':
+          break;
+        case '+':
+        case '-':
+          c = *(data+1);
+          check(c >= '0' && c <= '9', "invalid integer literal");
+          break;
+        default:
+          sentinel("invalid integer literal");
+      }
+      // PyLong_FromString insists that the string end in a NULL byte.
+      // I am *not* copying all that data.  Instead we lie a little bit
+      // about the const-ness of data, write a NULL over the format terminator
+      // and restore the original character when we're done.
+      c = data[len];
+      ((char*)data)[len] = '\0';
       v = PyLong_FromString((char *)data, &dataend, 10);
+      ((char*)data)[len] = c;
       check(dataend == data + len, "invalid integer literal");
       return v;
   }
